/*
 * Project name:
     Tilt click Board Example
 * Copyright:
     (c) Mikroelektronika, 2015.
 * Revision History:
     20150325:
       - initial release (DM);
 * Description:
     This is a simple demonstration of the Tilt click Board usage.
 * Test configuration:
     MCU:             ATmega32
                      http://www.atmel.com/Images/doc2503.pdf
     Dev. Board:      EasyAVR7
                      http://www.mikroe.com/easyavr/
     Oscillator:      Oscillator Frequency 8.0000 MHz, 8.0000 MHz Crystal
     ext. modules:    Tilt click board
                      http://www.mikroe.com/click/tilt/
     SW:              mikroC PRO for AVR
                      http://www.mikroe.com/mikroc/avr/
 * NOTES:
     - Place Tilt click board at the mikroBUS socket 1 on the EasyAVR v7 board.
     - Set J12 and J23 jumpers on EasyAVR v7 board on left for RS232 or on right for USB UART.
     - Turn on SW10.1 and SW10.2 (USB UART).
 */
 
sbit Tilt_V01 at PIND4_bit;
sbit Tilt_V02 at PIND2_bit;
sbit Tilt_V01_Direction at DDD4_bit;
sbit Tilt_V02_Direction at DDD2_bit;

void main() {
  Tilt_V01_Direction = 0;                                 // Set PD4 pin as input
  Tilt_V02_Direction = 0;                                 // Set PD2 pin as input

  UART1_Init(9600);                                       // Initialize UART module at 9600 bps
  Delay_ms(100);                                          // Wait for UART module to stabilize

  UART1_Write_Text("Start");
  UART1_Write(13);
  UART1_Write(10);
  
  while(1){
    if ((Tilt_V02 == 1) & (Tilt_V01 == 0)){
      UART1_Write_Text("Left");
      UART1_Write(13);
      UART1_Write(10);
    }
    
    if ((Tilt_V02 == 0) & (Tilt_V01 == 1)){
      UART1_Write_Text("Right");
      UART1_Write(13);
      UART1_Write(10);
    }
    
    if ((Tilt_V02 == 1) & (Tilt_V01 == 1)){
      UART1_Write_Text("Up");
      UART1_Write(13);
      UART1_Write(10);
    }
    
    if ((Tilt_V02 == 0) & (Tilt_V01 == 0)){
      UART1_Write_Text("Down");
      UART1_Write(13);
      UART1_Write(10);
    }
    
  delay_ms(250);
  }
}